@@ -14,6 +14,8 @@
 # classifiers.py
 # Copyright (C) 2014 Fracpete (fracpete at gmail dot com)
 
+import sys
+import os
 import javabridge
 import logging
 import getopt
@@ -667,18 +669,22 @@ class Evaluation(JavaObject):
             "(Lweka/classifiers/Classifier;Lweka/core/Instance;)D",
             classifier.jobject, inst.jobject)
 
-    def to_summary(self, title=None):
+    def to_summary(self, title=None, complexity=False):
         """
         Generates a summary.
         :param title: optional title
         :type title: str
+        :param complexity: whether to print the complexity information as well
+        :type complexity: bool
         :return: the summary
         :rtype: str
         """
         if title is None:
-            return javabridge.call(self.jobject, "toSummaryString", "()Ljava/lang/String;")
+            return javabridge.call(
+                self.jobject, "toSummaryString", "()Ljava/lang/String;")
         else:
-            return javabridge.call(self.jobject, "toSummaryString", "(Ljava/lang/String;)Ljava/lang/String;", title)
+            return javabridge.call(
+                self.jobject, "toSummaryString", "(Ljava/lang/String;Z)Ljava/lang/String;", title, complexity)
 
     def to_class_details(self, title=None):
         """
@@ -1453,42 +1459,13 @@ def main(args):
             jars = opt[1].split(os.pathsep)
         elif opt[0] == "-X":
             heap = opt[1]
-        elif opt[0] == "-t":
+        elif opt[0] in ["-v", "-o", "-i", "-k"]:
             params.append(opt[0])
-            params.append(opt[1])
-            train = opt[1]
-        elif opt[0] == "-T":
-            params.append(opt[0])
-            params.append(opt[1])
-        elif opt[0] == "-c":
-            params.append(opt[0])
-            params.append(opt[1])
-        elif opt[0] == "-d":
-            params.append(opt[0])
-            params.append(opt[1])
-        elif opt[0] == "-l":
-            params.append(opt[0])
-            params.append(opt[1])
-        elif opt[0] == "-x":
-            params.append(opt[0])
-            params.append(opt[1])
-        elif opt[0] == "-s":
-            params.append(opt[0])
-            params.append(opt[1])
-        elif opt[0] == "-v":
-            params.append(opt[0])
-        elif opt[0] == "-o":
-            params.append(opt[0])
-        elif opt[0] == "-i":
-            params.append(opt[0])
-        elif opt[0] == "-k":
-            params.append(opt[0])
-        elif opt[0] == "-m":
-            params.append(opt[0])
-            params.append(opt[1])
-        elif opt[0] == "-g":
+        elif opt[0] in ["-t", "-T", "-c", "-d", "-l", "-x", "-s", "-m", "-g"]:
             params.append(opt[0])
             params.append(opt[1])
+            if opt[0] == "-t":
+                train = opt[1]
 
     # check parameters
     if train is None:
@@ -1496,7 +1473,7 @@ def main(args):
 
     jvm.start(jars, max_heap_size=heap, packages=True)
 
-    logger.debug("Commandline: " + utils.join_options(args))
+    logger.debug("Commandline: " + wutils.join_options(args))
 
     try:
         classifier = Classifier(classname=optargs[0])
