@@ -346,34 +346,11 @@ def main(args):
             jars = opt[1].split(os.pathsep)
         elif opt[0] == "-X":
             heap = opt[1]
-        elif opt[0] == "-t":
-            params.append(opt[0])
-            params.append(opt[1])
-            train = opt[1]
-        elif opt[0] == "-T":
-            params.append(opt[0])
-            params.append(opt[1])
-        elif opt[0] == "-d":
-            params.append(opt[0])
-            params.append(opt[1])
-        elif opt[0] == "-l":
-            params.append(opt[0])
-            params.append(opt[1])
-        elif opt[0] == "-p":
-            params.append(opt[0])
-            params.append(opt[1])
-        elif opt[0] == "-x":
-            params.append(opt[0])
-            params.append(opt[1])
-        elif opt[0] == "-s":
-            params.append(opt[0])
-            params.append(opt[1])
-        elif opt[0] == "-c":
-            params.append(opt[0])
-            params.append(opt[1])
-        elif opt[0] == "-g":
+        elif opt[0] in ["-t", "-T", "-d", "-l", "-p", "-x", "-s", "-c", "-g"]:
             params.append(opt[0])
             params.append(opt[1])
+            if opt[0] == "-t":
+                train = opt[1]
 
     # check parameters
     if train is None:
